@@ -3,6 +3,14 @@ import os
 
 import pytest
 
+import gi
+
+gi.require_version('Gtk', '4.0')
+gi.require_version('Gdk', '4.0')
+gi.require_version('Adw', '1')
+gi.require_version('Gst', '1.0')
+gi.require_version('GstPbutils', '1.0')
+
 
 @pytest.fixture(scope='session', autouse=True)
 def install_l10n():
